
#include <unistd.h>
#include <string.h>
#include <fcntl.h>
#include <math.h>
#include "globdef.h"
#include "uidef.h"
#include "thrdef.h"
#include "sdrdef.h"
#include "fft1def.h"
#include "screendef.h"
#include "hwaredef.h"
#include "vernr.h"
#include "rusage.h"
#include "options.h"

void open_excalibur(void);



int init_excalibur(void)
{
int line;
char *looking;
looking="Looking for an Excalibur on the USB port.";
settextcolor(12);
lir_text(10,10,looking);
SNDLOG"\n%s",looking);
lir_text(10,11,"Reset CPU, USB and SDR hardware if system hangs here.");
lir_refresh_screen();
settextcolor(14);
open_excalibur();
settextcolor(7);
clear_lines(10,11);
lir_refresh_screen();
line=0;



/*
int i, k;
char s[80];
char *ss;
int *sdr_pi;
eeprom_prodid prodid;
FILE *perseus_file;
if(sdr != -1)
  {
  lir_text(5,5,"A Perseus is detected on the USB port.");
  lir_text(5,6,"Do you want to use it for RX input (Y/N)?");
qpers:;
  await_processed_keyboard();
  if(kill_all_flag) goto pers_errexit;
  if(lir_inkey == 'Y')
    {
#if(OSNUM == OS_FLAG_WINDOWS)
    ss=perseus_frname();
    if(ss == NULL)goto pers_errexit;
    sprintf(s,"USB Friendly device Name is: %s",ss);
    lir_text(2,8,s);
    SNDLOG"%s\n",s);
    ss=perseus_name();
    if(ss == NULL)goto pers_errexit;
    sprintf(s,"USB Device Name is: %s",ss);
    lir_text(2,9,s);
    SNDLOG"%s\n",s);
#else
    ss="Perseus";
#endif
    ui.rx_addev_no=PERSEUS_DEVICE_CODE;
    ui.rx_input_mode=IQ_DATA+DIGITAL_IQ+DWORD_INPUT;
    ui.rx_rf_channels=1;
    ui.rx_ad_channels=2;
    ui.rx_admode=0;
    perseus_eeprom_read((unsigned char*)&prodid,
                                       ADDR_EEPROM_PRODID, sizeof(prodid));
    if(kill_all_flag)goto pers_errexit;
    sprintf(s,"Microtelecom product code: 0x%04X", prodid.prodcode);
    lir_text(2,10,s);
    SNDLOG"%s\n",s);
    sprintf(s,"Serial Number: %05hd-%02hX%02hX-%02hX%02hX-%02hX%02hX",
				(unsigned short)prodid.sn,
				(unsigned short)prodid.signature[5],
				(unsigned short)prodid.signature[4],
				(unsigned short)prodid.signature[3],
				(unsigned short)prodid.signature[2],
				(unsigned short)prodid.signature[1],
				(unsigned short)prodid.signature[0]);
    lir_text(2,11,s);
    SNDLOG"%s\n",s);
    sprintf(s,"Hardware version/revision: %d.%d",
                         (unsigned)prodid.hwver, (unsigned)prodid.hwrel);
    lir_text(2,12,s);
    SNDLOG"%s\n",s);
    lir_text(10,16,"PRESS ANY KEY");
    await_processed_keyboard();
    if(kill_all_flag) goto pers_errexit;
    clear_screen();
    sprintf(s,"%s selected for input",ss);
    lir_text(10,line,s);
    line+=2;
#if(OSNUM == OS_FLAG_WINDOWS)
    for(i=0; i<MAX_PERSEUS_RATES; i++)
      {
      perseus_rates[i]=PERSEUS_SAMPLING_CLOCK/rate_factor[i];
      }
    no_of_perseus_rates=MAX_PERSEUS_RATES;
#else     
    fill_perseus_rates();
    for(i=0; i<no_of_perseus_rates; i++)
      {
      rate_factor[i]=PERSEUS_SAMPLING_CLOCK/perseus_rates[i];
      }
#endif    
    k=no_of_perseus_rates-1;
    if(ui.operator_skil == OPERATOR_SKIL_NEWCOMER)k-=2;
    for(i=0; i<no_of_perseus_rates; i++)
      {
      if(i>k)settextcolor(8);
      if(perseus_rates[i] > 999999.9)
        {
        sprintf(s,"%d %8.3f MHz ",i,0.000001*perseus_rates[i]);
        }
      else
        {
        sprintf(s,"%d %8.3f kHz ",i,0.001*perseus_rates[i]);
        }
      lir_text(5,line,s);
      line++;
      }
    settextcolor(7);
    line++;
    sprintf(s,"Set USB sampling rate (by number 0 to %d)",k);
    lir_text(5,line,s);
    pers.rate_no=lir_get_integer(50, line, 2, 0, k);
    if(kill_all_flag)goto pers_errexit;
    line++;
    if(ui.operator_skil == OPERATOR_SKIL_NEWCOMER)
      {
      pers.clock_adjust=0;
      }
    else
      {
      sprintf(s,"Set sampling clock shift (Hz))");
      lir_text(5,line,s);
      pers.clock_adjust=lir_get_integer(50, line, 5,-10000,10000);
      if(kill_all_flag)goto pers_errexit;
      line++;
      }
    adjusted_sdr_clock=PERSEUS_SAMPLING_CLOCK+pers.clock_adjust;
    ui.rx_ad_speed=adjusted_sdr_clock/rate_factor[pers.rate_no];
    if(ui.operator_skil == OPERATOR_SKIL_NEWCOMER)
      {
      pers.presel=1;
      pers.preamp=1;
      pers.dither=1;
      }
    else
      {
      lir_text(5,line,"Enable preselector ? (0/1)");
      pers.presel=lir_get_integer(32, line, 1, 0, 1);
      if(kill_all_flag)goto pers_errexit;
      line++;
      lir_text(5,line,"Enable preamp ? (0/1)");
      pers.preamp=lir_get_integer(27, line, 1, 0, 1);
      if(kill_all_flag)goto pers_errexit;
      line++;
      lir_text(5,line,"Enable dither ? (0/1)");
      pers.dither=lir_get_integer(27, line, 1, 0, 1);
      if(kill_all_flag)goto pers_errexit;
      line++;
      }
      
// i=perseus_fpga_config(descr, perseus_bitstream_names[pers.rate_no]);
     
    pers.check=PERSEUS_PAR_VERNR;
    perseus_file=fopen(perseus_parfil_name,"w");
    if(perseus_file == NULL)
      {
pers_errexit:;
      close_perseus();
      clear_screen();
      ui.rx_addev_no=-1;
      return 0;
      }
    sdr_pi=(void*)(&pers);
    for(i=0; i<MAX_PERSEUS_PARM; i++)
      {
      fprintf(perseus_file,"%s [%d]\n",perseus_parm_text[i],sdr_pi[i]);
      }
    parfile_end(perseus_file);
    }
  else
    {
    if(lir_inkey != 'N')goto qpers;
    clear_screen();
    }
  close_perseus();
  sdr=-1;
  }
else
  {
  SNDLOG"open_perseus failed.\n");
  }
return line;
*/
return 0;
}

